aboutsummaryrefslogtreecommitdiff
path: root/t
diff options
context:
space:
mode:
authorJunio C Hamano <gitster@pobox.com>2025-03-06 14:06:31 -0800
committerJunio C Hamano <gitster@pobox.com>2025-03-06 14:06:31 -0800
commit62c58891e177bb3860ab19d2dc2e23909759c6ed (patch)
tree85986060f2cf04b2a4d15a800a026b82285465f6 /t
parente969bc875963a10890d61ba84eab3a460bd9e535 (diff)
parent61cd812130bda9c8996c90283501ee00c029c7a4 (diff)
downloadgit-62c58891e177bb3860ab19d2dc2e23909759c6ed.tar.xz
Merge branch 'tz/doc-txt-to-adoc-fixes'
Fallouts from recent renaming of documentation files from .txt suffix to the new .adoc suffix have been corrected. * tz/doc-txt-to-adoc-fixes: (38 commits) xdiff: *.txt -> *.adoc fixes unpack-trees.c: *.txt -> *.adoc fixes transport.h: *.txt -> *.adoc fixes trace2/tr2_sysenv.c: *.txt -> *.adoc fixes trace2.h: *.txt -> *.adoc fixes t6434: *.txt -> *.adoc fixes t6012: *.txt -> *.adoc fixes t/helper/test-rot13-filter.c: *.txt -> *.adoc fixes simple-ipc.h: *.txt -> *.adoc fixes setup.c: *.txt -> *.adoc fixes refs.h: *.txt -> *.adoc fixes pseudo-merge.h: *.txt -> *.adoc fixes parse-options.h: *.txt -> *.adoc fixes object-name.c: *.txt -> *.adoc fixes list-objects-filter-options.h: *.txt -> *.adoc fixes fsck.h: *.txt -> *.adoc fixes diffcore.h: *.txt -> *.adoc fixes diff.h: *.txt -> *.adoc fixes contrib/long-running-filter: *.txt -> *.adoc fixes config.c: *.txt -> *.adoc fixes ...
Diffstat (limited to 't')
-rw-r--r--t/helper/test-rot13-filter.c2
-rwxr-xr-xt/t0450-txt-doc-vs-help.sh50
-rw-r--r--t/t0450/adoc-help-mismatches (renamed from t/t0450/txt-help-mismatches)0
-rwxr-xr-xt/t6012-rev-list-simplify.sh2
-rwxr-xr-xt/t6434-merge-recursive-rename-options.sh2
5 files changed, 28 insertions, 28 deletions
diff --git a/t/helper/test-rot13-filter.c b/t/helper/test-rot13-filter.c
index ff407b575c..722b1cbe77 100644
--- a/t/helper/test-rot13-filter.c
+++ b/t/helper/test-rot13-filter.c
@@ -1,6 +1,6 @@
/*
* Example implementation for the Git filter protocol version 2
- * See Documentation/gitattributes.txt, section "Filter Protocol"
+ * See Documentation/gitattributes.adoc, section "Filter Protocol"
*
* Usage: test-tool rot13-filter [--always-delay] --log=<path> <capabilities>
*
diff --git a/t/t0450/txt-help-mismatches b/t/t0450/adoc-help-mismatches
index c4a15fd0cb..c4a15fd0cb 100644
--- a/t/t0450/txt-help-mismatches
+++ b/t/t0450/adoc-help-mismatches
diff --git a/t/t6012-rev-list-simplify.sh b/t/t6012-rev-list-simplify.sh
index de1e87f162..4cecb6224c 100755
--- a/t/t6012-rev-list-simplify.sh
+++ b/t/t6012-rev-list-simplify.sh
@@ -177,7 +177,7 @@ test_expect_success '--full-diff is not affected by --parents' '
# \ / /\ /
# `---X--' `---Y--'
#
-# This example is explained in Documentation/rev-list-options.txt
+# This example is explained in Documentation/rev-list-options.adoc
test_expect_success 'setup rebuild repo' '
rm -rf .git * &&
diff --git a/t/t6434-merge-recursive-rename-options.sh b/t/t6434-merge-recursive-rename-options.sh
index a11707835b..6e913c30a1 100755
--- a/t/t6434-merge-recursive-rename-options.sh
+++ b/t/t6434-merge-recursive-rename-options.sh
@@ -22,7 +22,7 @@ R075 2-old 2-new
R100 3-old 3-new
Actual similarity indices are parsed from diff output. We rely on the fact that
-they are rounded down (see, e.g., Documentation/diff-generate-patch.txt, which
+they are rounded down (see, e.g., Documentation/diff-generate-patch.adoc, which
mentions this in a different context).
'
diff --git a/t/t0450-txt-doc-vs-help.sh b/t/t0450-txt-doc-vs-help.sh
index 853101b86e..2f7504ae7e 100755
--- a/t/t0450-txt-doc-vs-help.sh
+++ b/t/t0450-txt-doc-vs-help.sh
@@ -1,6 +1,6 @@
#!/bin/sh
-test_description='assert (unbuilt) Documentation/*.txt and -h output
+test_description='assert (unbuilt) Documentation/*.adoc and -h output
Run this with --debug to see a summary of where we still fail to make
the two versions consistent with one another.'
@@ -11,11 +11,11 @@ test_expect_success 'setup: list of builtins' '
git --list-cmds=builtins >builtins
'
-test_expect_success 'list of txt and help mismatches is sorted' '
- sort -u "$TEST_DIRECTORY"/t0450/txt-help-mismatches >expect &&
- if ! test_cmp expect "$TEST_DIRECTORY"/t0450/txt-help-mismatches
+test_expect_success 'list of adoc and help mismatches is sorted' '
+ sort -u "$TEST_DIRECTORY"/t0450/adoc-help-mismatches >expect &&
+ if ! test_cmp expect "$TEST_DIRECTORY"/t0450/adoc-help-mismatches
then
- BUG "please keep the list of txt and help mismatches sorted"
+ BUG "please keep the list of adoc and help mismatches sorted"
fi
'
@@ -40,20 +40,20 @@ help_to_synopsis () {
echo "$out"
}
-builtin_to_txt () {
- echo "$GIT_BUILD_DIR/Documentation/git-$1.txt"
+builtin_to_adoc () {
+ echo "$GIT_BUILD_DIR/Documentation/git-$1.adoc"
}
-txt_to_synopsis () {
+adoc_to_synopsis () {
builtin="$1" &&
out_dir="out/$builtin" &&
- out="$out_dir/txt.synopsis" &&
+ out="$out_dir/adoc.synopsis" &&
if test -f "$out"
then
echo "$out" &&
return 0
fi &&
- b2t="$(builtin_to_txt "$builtin")" &&
+ b2t="$(builtin_to_adoc "$builtin")" &&
sed -n \
-E '/^\[(verse|synopsis)\]$/,/^$/ {
/^$/d;
@@ -109,29 +109,29 @@ do
fi
'
- txt="$(builtin_to_txt "$builtin")" &&
- preq="$(echo BUILTIN_TXT_$builtin | tr '[:lower:]-' '[:upper:]_')" &&
+ adoc="$(builtin_to_adoc "$builtin")" &&
+ preq="$(echo BUILTIN_ADOC_$builtin | tr '[:lower:]-' '[:upper:]_')" &&
- if test -f "$txt"
+ if test -f "$adoc"
then
test_set_prereq "$preq"
fi &&
- # *.txt output assertions
- test_expect_success "$preq" "$builtin *.txt SYNOPSIS has dashed labels" '
- check_dashed_labels "$(txt_to_synopsis "$builtin")"
+ # *.adoc output assertions
+ test_expect_success "$preq" "$builtin *.adoc SYNOPSIS has dashed labels" '
+ check_dashed_labels "$(adoc_to_synopsis "$builtin")"
'
# *.txt output consistency assertions
result=
- if grep -q "^$builtin$" "$TEST_DIRECTORY"/t0450/txt-help-mismatches
+ if grep -q "^$builtin$" "$TEST_DIRECTORY"/t0450/adoc-help-mismatches
then
result=failure
else
result=success
fi &&
test_expect_$result "$preq" "$builtin -h output and SYNOPSIS agree" '
- t2s="$(txt_to_synopsis "$builtin")" &&
+ t2s="$(adoc_to_synopsis "$builtin")" &&
if test "$builtin" = "merge-tree"
then
test_when_finished "rm -f t2s.new" &&
@@ -140,17 +140,17 @@ do
fi &&
h2s="$(help_to_synopsis "$builtin")" &&
# The *.txt and -h use different spacing for the
# alignment of continued usage output, normalize it.
- align_after_nl "$builtin" <"$t2s" >txt &&
+ align_after_nl "$builtin" <"$t2s" >adoc &&
align_after_nl "$builtin" <"$h2s" >help &&
- test_cmp txt help
+ test_cmp adoc help
'
- if test_have_prereq "$preq" && test -e txt && test -e help
+ if test_have_prereq "$preq" && test -e adoc && test -e help
then
test_debug '
- if test_cmp txt help >cmp 2>/dev/null
+ if test_cmp adoc help >cmp 2>/dev/null
then
echo "=== DONE: $builtin ==="
else
@@ -161,7 +161,7 @@ do
# Not in test_expect_success in case --run is being
# used with --debug
- rm -f txt help tmp 2>/dev/null
+ rm -f adoc help tmp 2>/dev/null
fi
done <builtins
@@ -109,29 +109,29 @@ do
'
- # *.txt output consistency assertions
+ # *.adoc output consistency assertions
result=
@@ -140,17 +140,17 @@ do
fi &&
h2s="$(help_to_synopsis "$builtin")" &&
- # The *.txt and -h use different spacing for the
+ # The *.adoc and -h use different spacing for the
# alignment of continued usage output, normalize it.